==> haskell-ghcide-test-utils-1.9.0.0-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-7aKUBapJEXOGtWq7nw27qr
key:                  ghcide-test-utils-1.9.0.0-7aKUBapJEXOGtWq7nw27qr
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  b7dc908a0a169f7e3f48522ebe296b9b
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-7aKUBapJEXOGtWq7nw27qr
depends:
    aeson-2.1.2.1-7IgTEIjsesxDBKStPrg8Ee base-4.16.4.0
    containers-0.6.5.1 data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3
    directory-1.3.6.2 extra-1.7.16-CDnJ4IIZiy49QmNU3HquQ1
    filepath-1.4.2.2 ghcide-1.10.0.0-LhGUUK2X0Mx8y8BmxO8cFF
    hls-plugin-api-1.6.0.0-KQiZtRdUhMLDCvINTWQPQE
    lens-5.2.3-3BG1BTsYajWH51jWMi4vYO
    lsp-test-0.14.1.0-GuWrmhHrWvgKr5Az8xb49i
    lsp-types-1.6.0.1-4G2dWo8pHR34g3PMsDLWrU
    tasty-hunit-0.10.1-5ONeb0NXzJ8FVtbIW79oZz text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-test-utils-1.9.0.0-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide-test-utils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghcide-test-utils
version:              1.9.0.0
visibility:           public
id:                   ghcide-test-utils-1.9.0.0-Ax8ZvCCS6jc55g0nOm1D1u
key:                  ghcide-test-utils-1.9.0.0-Ax8ZvCCS6jc55g0nOm1D1u
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2022
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             Test utils for ghcide
description:          Test utils for ghcide
category:             Development
abi:                  2f4e3374518f73608c214bd7bd8e6c9b
exposed:              True
exposed-modules:      Development.IDE.Test Development.IDE.Test.Diagnostic
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ghcide-test-utils-1.9.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ghcide-test-utils-1.9.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide-test-utils
hs-libraries:         HSghcide-test-utils-1.9.0.0-Ax8ZvCCS6jc55g0nOm1D1u
depends:
    aeson-2.1.2.1-7IgTEIjsesxDBKStPrg8Ee base-4.16.4.0
    containers-0.6.5.1 data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3
    directory-1.3.6.2 extra-1.7.16-CDnJ4IIZiy49QmNU3HquQ1
    filepath-1.4.2.2 ghcide-1.10.0.0-7qHaHD6v1nAJJA9gYgzgDU
    hls-plugin-api-1.6.0.0-AfH6u1YbTqnFo6DBEzB1dD
    lens-5.2.3-3BG1BTsYajWH51jWMi4vYO
    lsp-test-0.14.1.0-AipOyU5rzFv1CP6U5f1c9D
    lsp-types-1.6.0.1-4G2dWo8pHR34g3PMsDLWrU
    tasty-hunit-0.10.1-5ONeb0NXzJ8FVtbIW79oZz text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-ghcide-test-utils/html/ghcide-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-ghcide-test-utils/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
